
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "e-shell-enumtypes.h"
/* enumerations from "e-shell.h" */
#include "e-shell.h"
GType
e_shell_quit_reason_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_SHELL_QUIT_ACTION,
			  "E_SHELL_QUIT_ACTION",
			  "action" },
			{ E_SHELL_QUIT_LAST_WINDOW,
			  "E_SHELL_QUIT_LAST_WINDOW",
			  "last-window" },
			{ E_SHELL_QUIT_OPTION,
			  "E_SHELL_QUIT_OPTION",
			  "option" },
			{ E_SHELL_QUIT_REMOTE_REQUEST,
			  "E_SHELL_QUIT_REMOTE_REQUEST",
			  "remote-request" },
			{ E_SHELL_QUIT_SESSION_REQUEST,
			  "E_SHELL_QUIT_SESSION_REQUEST",
			  "session-request" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EShellQuitReason"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

/* Generated data ends here */

