/*
 * SPDX-FileCopyrightText: (C) 1999-2008 Novell, Inc. (www.novell.com)
 * SPDX-License-Identifier: LGPL-2.1-or-later
 * SPDX-FileContributor: Bolian Yin <bolian.yin@sun.com>
 */

/* Evolution Accessibility
*/

#ifndef _EA_CALENDAR_H__
#define _EA_CALENDAR_H__

void e_calendar_a11y_init (void);
void e_day_view_main_item_a11y_init (void);
void e_week_view_main_item_a11y_init (void);

#endif /* _EA_CALENDAR_H__ */
