/*
 * SPDX-FileCopyrightText: (C) 1999-2008 Novell, Inc. (www.novell.com)
 * SPDX-License-Identifier: LGPL-2.1-or-later
 * SPDX-FileContributor: Chris Toshok <toshok@ximian.com>
 */

#ifndef _AUTOCOMPLETION_CONFIG_H
#define _AUTOCOMPLETION_CONFIG_H

#include <shell/e-shell.h>

G_BEGIN_DECLS

GtkWidget *	autocompletion_config_new	(EPreferencesWindow *window);

G_END_DECLS

#endif /* _AUTOCOMPLETION_CONFIG_H */
