/*
 * SPDX-FileCopyrightText: (C) 1999-2008 Novell, Inc. (www.novell.com)
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef E_MAIL_CONFIG_HOOK_H
#define E_MAIL_CONFIG_HOOK_H

#include <glib-object.h>

G_BEGIN_DECLS

void e_mail_config_hook_register_type (GTypeModule *type_module);

G_END_DECLS

#endif /* E_MAIL_CONFIG_HOOK_H */
