/*
 * SPDX-FileCopyrightText: (C) 1999-2008 Novell, Inc. (www.novell.com)
 * SPDX-License-Identifier: LGPL-2.1-or-later
 * SPDX-FileContributor: Chris Toshok <toshok@ximian.com>
 */

#ifndef _SMIME_COMPONENT_H_
#define _SMIME_COMPONENT_H_

void smime_component_init (void);

#endif /* _SMIME_COMPONENT_H_ */
