
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include "e-util-enumtypes.h"
/* enumerations from "e-util-enums.h" */
#include "e-util-enums.h"
GType
e_activity_state_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_ACTIVITY_RUNNING,
			  "E_ACTIVITY_RUNNING",
			  "running" },
			{ E_ACTIVITY_WAITING,
			  "E_ACTIVITY_WAITING",
			  "waiting" },
			{ E_ACTIVITY_CANCELLED,
			  "E_ACTIVITY_CANCELLED",
			  "cancelled" },
			{ E_ACTIVITY_COMPLETED,
			  "E_ACTIVITY_COMPLETED",
			  "completed" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EActivityState"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_automatic_action_policy_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_AUTOMATIC_ACTION_POLICY_ASK,
			  "E_AUTOMATIC_ACTION_POLICY_ASK",
			  "ask" },
			{ E_AUTOMATIC_ACTION_POLICY_ALWAYS,
			  "E_AUTOMATIC_ACTION_POLICY_ALWAYS",
			  "always" },
			{ E_AUTOMATIC_ACTION_POLICY_NEVER,
			  "E_AUTOMATIC_ACTION_POLICY_NEVER",
			  "never" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EAutomaticActionPolicy"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_date_weekday_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_DATE_BAD_WEEKDAY,
			  "E_DATE_BAD_WEEKDAY",
			  "bad-weekday" },
			{ E_DATE_MONDAY,
			  "E_DATE_MONDAY",
			  "monday" },
			{ E_DATE_TUESDAY,
			  "E_DATE_TUESDAY",
			  "tuesday" },
			{ E_DATE_WEDNESDAY,
			  "E_DATE_WEDNESDAY",
			  "wednesday" },
			{ E_DATE_THURSDAY,
			  "E_DATE_THURSDAY",
			  "thursday" },
			{ E_DATE_FRIDAY,
			  "E_DATE_FRIDAY",
			  "friday" },
			{ E_DATE_SATURDAY,
			  "E_DATE_SATURDAY",
			  "saturday" },
			{ E_DATE_SUNDAY,
			  "E_DATE_SUNDAY",
			  "sunday" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EDateWeekday"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_duration_type_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_DURATION_MINUTES,
			  "E_DURATION_MINUTES",
			  "minutes" },
			{ E_DURATION_HOURS,
			  "E_DURATION_HOURS",
			  "hours" },
			{ E_DURATION_DAYS,
			  "E_DURATION_DAYS",
			  "days" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EDurationType"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_image_loading_policy_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_IMAGE_LOADING_POLICY_NEVER,
			  "E_IMAGE_LOADING_POLICY_NEVER",
			  "never" },
			{ E_IMAGE_LOADING_POLICY_SOMETIMES,
			  "E_IMAGE_LOADING_POLICY_SOMETIMES",
			  "sometimes" },
			{ E_IMAGE_LOADING_POLICY_ALWAYS,
			  "E_IMAGE_LOADING_POLICY_ALWAYS",
			  "always" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EImageLoadingPolicy"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_insert_content_flags_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GFlagsValue values[] = {
			{ E_CONTENT_EDITOR_INSERT_NONE,
			  "E_CONTENT_EDITOR_INSERT_NONE",
			  "none" },
			{ E_CONTENT_EDITOR_INSERT_CONVERT,
			  "E_CONTENT_EDITOR_INSERT_CONVERT",
			  "convert" },
			{ E_CONTENT_EDITOR_INSERT_QUOTE_CONTENT,
			  "E_CONTENT_EDITOR_INSERT_QUOTE_CONTENT",
			  "quote-content" },
			{ E_CONTENT_EDITOR_INSERT_REPLACE_ALL,
			  "E_CONTENT_EDITOR_INSERT_REPLACE_ALL",
			  "replace-all" },
			{ E_CONTENT_EDITOR_INSERT_TEXT_HTML,
			  "E_CONTENT_EDITOR_INSERT_TEXT_HTML",
			  "text-html" },
			{ E_CONTENT_EDITOR_INSERT_TEXT_PLAIN,
			  "E_CONTENT_EDITOR_INSERT_TEXT_PLAIN",
			  "text-plain" },
			{ E_CONTENT_EDITOR_INSERT_CONVERT_PREFER_PRE,
			  "E_CONTENT_EDITOR_INSERT_CONVERT_PREFER_PRE",
			  "convert-prefer-pre" },
			{ E_CONTENT_EDITOR_INSERT_CLEANUP_SIGNATURE_ID,
			  "E_CONTENT_EDITOR_INSERT_CLEANUP_SIGNATURE_ID",
			  "cleanup-signature-id" },
			{ E_CONTENT_EDITOR_INSERT_FROM_PLAIN_TEXT,
			  "E_CONTENT_EDITOR_INSERT_FROM_PLAIN_TEXT",
			  "from-plain-text" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_flags_register_static (
			g_intern_static_string ("EContentEditorInsertContentFlags"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_get_content_flags_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GFlagsValue values[] = {
			{ E_CONTENT_EDITOR_GET_INLINE_IMAGES,
			  "E_CONTENT_EDITOR_GET_INLINE_IMAGES",
			  "inline-images" },
			{ E_CONTENT_EDITOR_GET_RAW_BODY_HTML,
			  "E_CONTENT_EDITOR_GET_RAW_BODY_HTML",
			  "raw-body-html" },
			{ E_CONTENT_EDITOR_GET_RAW_BODY_PLAIN,
			  "E_CONTENT_EDITOR_GET_RAW_BODY_PLAIN",
			  "raw-body-plain" },
			{ E_CONTENT_EDITOR_GET_RAW_BODY_STRIPPED,
			  "E_CONTENT_EDITOR_GET_RAW_BODY_STRIPPED",
			  "raw-body-stripped" },
			{ E_CONTENT_EDITOR_GET_RAW_DRAFT,
			  "E_CONTENT_EDITOR_GET_RAW_DRAFT",
			  "raw-draft" },
			{ E_CONTENT_EDITOR_GET_TO_SEND_HTML,
			  "E_CONTENT_EDITOR_GET_TO_SEND_HTML",
			  "to-send-html" },
			{ E_CONTENT_EDITOR_GET_TO_SEND_PLAIN,
			  "E_CONTENT_EDITOR_GET_TO_SEND_PLAIN",
			  "to-send-plain" },
			{ E_CONTENT_EDITOR_GET_ALL,
			  "E_CONTENT_EDITOR_GET_ALL",
			  "all" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_flags_register_static (
			g_intern_static_string ("EContentEditorGetContentFlags"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_node_flags_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GFlagsValue values[] = {
			{ E_CONTENT_EDITOR_NODE_UNKNOWN,
			  "E_CONTENT_EDITOR_NODE_UNKNOWN",
			  "unknown" },
			{ E_CONTENT_EDITOR_NODE_IS_ANCHOR,
			  "E_CONTENT_EDITOR_NODE_IS_ANCHOR",
			  "is-anchor" },
			{ E_CONTENT_EDITOR_NODE_IS_H_RULE,
			  "E_CONTENT_EDITOR_NODE_IS_H_RULE",
			  "is-h-rule" },
			{ E_CONTENT_EDITOR_NODE_IS_IMAGE,
			  "E_CONTENT_EDITOR_NODE_IS_IMAGE",
			  "is-image" },
			{ E_CONTENT_EDITOR_NODE_IS_TABLE,
			  "E_CONTENT_EDITOR_NODE_IS_TABLE",
			  "is-table" },
			{ E_CONTENT_EDITOR_NODE_IS_TABLE_CELL,
			  "E_CONTENT_EDITOR_NODE_IS_TABLE_CELL",
			  "is-table-cell" },
			{ E_CONTENT_EDITOR_NODE_IS_TEXT,
			  "E_CONTENT_EDITOR_NODE_IS_TEXT",
			  "is-text" },
			{ E_CONTENT_EDITOR_NODE_IS_TEXT_COLLAPSED,
			  "E_CONTENT_EDITOR_NODE_IS_TEXT_COLLAPSED",
			  "is-text-collapsed" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_flags_register_static (
			g_intern_static_string ("EContentEditorNodeFlags"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_block_format_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_NONE,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_NONE",
			  "none" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_PARAGRAPH,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_PARAGRAPH",
			  "paragraph" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_PRE,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_PRE",
			  "pre" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_ADDRESS,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_ADDRESS",
			  "address" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_H1,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_H1",
			  "h1" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_H2,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_H2",
			  "h2" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_H3,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_H3",
			  "h3" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_H4,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_H4",
			  "h4" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_H5,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_H5",
			  "h5" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_H6,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_H6",
			  "h6" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_UNORDERED_LIST,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_UNORDERED_LIST",
			  "unordered-list" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_ORDERED_LIST,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_ORDERED_LIST",
			  "ordered-list" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_ORDERED_LIST_ROMAN,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_ORDERED_LIST_ROMAN",
			  "ordered-list-roman" },
			{ E_CONTENT_EDITOR_BLOCK_FORMAT_ORDERED_LIST_ALPHA,
			  "E_CONTENT_EDITOR_BLOCK_FORMAT_ORDERED_LIST_ALPHA",
			  "ordered-list-alpha" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EContentEditorBlockFormat"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_font_size_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_CONTENT_EDITOR_FONT_SIZE_TINY,
			  "E_CONTENT_EDITOR_FONT_SIZE_TINY",
			  "tiny" },
			{ E_CONTENT_EDITOR_FONT_SIZE_SMALL,
			  "E_CONTENT_EDITOR_FONT_SIZE_SMALL",
			  "small" },
			{ E_CONTENT_EDITOR_FONT_SIZE_NORMAL,
			  "E_CONTENT_EDITOR_FONT_SIZE_NORMAL",
			  "normal" },
			{ E_CONTENT_EDITOR_FONT_SIZE_BIG,
			  "E_CONTENT_EDITOR_FONT_SIZE_BIG",
			  "big" },
			{ E_CONTENT_EDITOR_FONT_SIZE_BIGGER,
			  "E_CONTENT_EDITOR_FONT_SIZE_BIGGER",
			  "bigger" },
			{ E_CONTENT_EDITOR_FONT_SIZE_LARGE,
			  "E_CONTENT_EDITOR_FONT_SIZE_LARGE",
			  "large" },
			{ E_CONTENT_EDITOR_FONT_SIZE_VERY_LARGE,
			  "E_CONTENT_EDITOR_FONT_SIZE_VERY_LARGE",
			  "very-large" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EContentEditorFontSize"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_alignment_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_CONTENT_EDITOR_ALIGNMENT_NONE,
			  "E_CONTENT_EDITOR_ALIGNMENT_NONE",
			  "none" },
			{ E_CONTENT_EDITOR_ALIGNMENT_LEFT,
			  "E_CONTENT_EDITOR_ALIGNMENT_LEFT",
			  "left" },
			{ E_CONTENT_EDITOR_ALIGNMENT_CENTER,
			  "E_CONTENT_EDITOR_ALIGNMENT_CENTER",
			  "center" },
			{ E_CONTENT_EDITOR_ALIGNMENT_RIGHT,
			  "E_CONTENT_EDITOR_ALIGNMENT_RIGHT",
			  "right" },
			{ E_CONTENT_EDITOR_ALIGNMENT_JUSTIFY,
			  "E_CONTENT_EDITOR_ALIGNMENT_JUSTIFY",
			  "justify" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EContentEditorAlignment"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_granularity_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_CONTENT_EDITOR_GRANULARITY_CHARACTER,
			  "E_CONTENT_EDITOR_GRANULARITY_CHARACTER",
			  "character" },
			{ E_CONTENT_EDITOR_GRANULARITY_WORD,
			  "E_CONTENT_EDITOR_GRANULARITY_WORD",
			  "word" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EContentEditorGranularity"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_command_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_CONTENT_EDITOR_COMMAND_BACKGROUND_COLOR,
			  "E_CONTENT_EDITOR_COMMAND_BACKGROUND_COLOR",
			  "background-color" },
			{ E_CONTENT_EDITOR_COMMAND_BOLD,
			  "E_CONTENT_EDITOR_COMMAND_BOLD",
			  "bold" },
			{ E_CONTENT_EDITOR_COMMAND_COPY,
			  "E_CONTENT_EDITOR_COMMAND_COPY",
			  "copy" },
			{ E_CONTENT_EDITOR_COMMAND_CREATE_LINK,
			  "E_CONTENT_EDITOR_COMMAND_CREATE_LINK",
			  "create-link" },
			{ E_CONTENT_EDITOR_COMMAND_CUT,
			  "E_CONTENT_EDITOR_COMMAND_CUT",
			  "cut" },
			{ E_CONTENT_EDITOR_COMMAND_DEFAULT_PARAGRAPH_SEPARATOR,
			  "E_CONTENT_EDITOR_COMMAND_DEFAULT_PARAGRAPH_SEPARATOR",
			  "default-paragraph-separator" },
			{ E_CONTENT_EDITOR_COMMAND_DELETE,
			  "E_CONTENT_EDITOR_COMMAND_DELETE",
			  "delete" },
			{ E_CONTENT_EDITOR_COMMAND_FIND_STRING,
			  "E_CONTENT_EDITOR_COMMAND_FIND_STRING",
			  "find-string" },
			{ E_CONTENT_EDITOR_COMMAND_FONT_NAME,
			  "E_CONTENT_EDITOR_COMMAND_FONT_NAME",
			  "font-name" },
			{ E_CONTENT_EDITOR_COMMAND_FONT_SIZE,
			  "E_CONTENT_EDITOR_COMMAND_FONT_SIZE",
			  "font-size" },
			{ E_CONTENT_EDITOR_COMMAND_FONT_SIZE_DELTA,
			  "E_CONTENT_EDITOR_COMMAND_FONT_SIZE_DELTA",
			  "font-size-delta" },
			{ E_CONTENT_EDITOR_COMMAND_FORE_COLOR,
			  "E_CONTENT_EDITOR_COMMAND_FORE_COLOR",
			  "fore-color" },
			{ E_CONTENT_EDITOR_COMMAND_FORMAT_BLOCK,
			  "E_CONTENT_EDITOR_COMMAND_FORMAT_BLOCK",
			  "format-block" },
			{ E_CONTENT_EDITOR_COMMAND_FORWARD_DELETE,
			  "E_CONTENT_EDITOR_COMMAND_FORWARD_DELETE",
			  "forward-delete" },
			{ E_CONTENT_EDITOR_COMMAND_HILITE_COLOR,
			  "E_CONTENT_EDITOR_COMMAND_HILITE_COLOR",
			  "hilite-color" },
			{ E_CONTENT_EDITOR_COMMAND_INDENT,
			  "E_CONTENT_EDITOR_COMMAND_INDENT",
			  "indent" },
			{ E_CONTENT_EDITOR_COMMAND_INSERT_HTML,
			  "E_CONTENT_EDITOR_COMMAND_INSERT_HTML",
			  "insert-html" },
			{ E_CONTENT_EDITOR_COMMAND_INSERT_HORIZONTAL_RULE,
			  "E_CONTENT_EDITOR_COMMAND_INSERT_HORIZONTAL_RULE",
			  "insert-horizontal-rule" },
			{ E_CONTENT_EDITOR_COMMAND_INSERT_IMAGE,
			  "E_CONTENT_EDITOR_COMMAND_INSERT_IMAGE",
			  "insert-image" },
			{ E_CONTENT_EDITOR_COMMAND_INSERT_LINE_BREAK,
			  "E_CONTENT_EDITOR_COMMAND_INSERT_LINE_BREAK",
			  "insert-line-break" },
			{ E_CONTENT_EDITOR_COMMAND_INSERT_NEW_LINE_IN_QUOTED_CONTENT,
			  "E_CONTENT_EDITOR_COMMAND_INSERT_NEW_LINE_IN_QUOTED_CONTENT",
			  "insert-new-line-in-quoted-content" },
			{ E_CONTENT_EDITOR_COMMAND_INSERT_ORDERED_LIST,
			  "E_CONTENT_EDITOR_COMMAND_INSERT_ORDERED_LIST",
			  "insert-ordered-list" },
			{ E_CONTENT_EDITOR_COMMAND_INSERT_PARAGRAPH,
			  "E_CONTENT_EDITOR_COMMAND_INSERT_PARAGRAPH",
			  "insert-paragraph" },
			{ E_CONTENT_EDITOR_COMMAND_INSERT_TEXT,
			  "E_CONTENT_EDITOR_COMMAND_INSERT_TEXT",
			  "insert-text" },
			{ E_CONTENT_EDITOR_COMMAND_INSERT_UNORDERED_LIST,
			  "E_CONTENT_EDITOR_COMMAND_INSERT_UNORDERED_LIST",
			  "insert-unordered-list" },
			{ E_CONTENT_EDITOR_COMMAND_ITALIC,
			  "E_CONTENT_EDITOR_COMMAND_ITALIC",
			  "italic" },
			{ E_CONTENT_EDITOR_COMMAND_JUSTIFY_CENTER,
			  "E_CONTENT_EDITOR_COMMAND_JUSTIFY_CENTER",
			  "justify-center" },
			{ E_CONTENT_EDITOR_COMMAND_JUSTIFY_FULL,
			  "E_CONTENT_EDITOR_COMMAND_JUSTIFY_FULL",
			  "justify-full" },
			{ E_CONTENT_EDITOR_COMMAND_JUSTIFY_LEFT,
			  "E_CONTENT_EDITOR_COMMAND_JUSTIFY_LEFT",
			  "justify-left" },
			{ E_CONTENT_EDITOR_COMMAND_JUSTIFY_NONE,
			  "E_CONTENT_EDITOR_COMMAND_JUSTIFY_NONE",
			  "justify-none" },
			{ E_CONTENT_EDITOR_COMMAND_JUSTIFY_RIGHT,
			  "E_CONTENT_EDITOR_COMMAND_JUSTIFY_RIGHT",
			  "justify-right" },
			{ E_CONTENT_EDITOR_COMMAND_OUTDENT,
			  "E_CONTENT_EDITOR_COMMAND_OUTDENT",
			  "outdent" },
			{ E_CONTENT_EDITOR_COMMAND_PASTE,
			  "E_CONTENT_EDITOR_COMMAND_PASTE",
			  "paste" },
			{ E_CONTENT_EDITOR_COMMAND_PASTE_AND_MATCH_STYLE,
			  "E_CONTENT_EDITOR_COMMAND_PASTE_AND_MATCH_STYLE",
			  "paste-and-match-style" },
			{ E_CONTENT_EDITOR_COMMAND_PASTE_AS_PLAIN_TEXT,
			  "E_CONTENT_EDITOR_COMMAND_PASTE_AS_PLAIN_TEXT",
			  "paste-as-plain-text" },
			{ E_CONTENT_EDITOR_COMMAND_PRINT,
			  "E_CONTENT_EDITOR_COMMAND_PRINT",
			  "print" },
			{ E_CONTENT_EDITOR_COMMAND_REDO,
			  "E_CONTENT_EDITOR_COMMAND_REDO",
			  "redo" },
			{ E_CONTENT_EDITOR_COMMAND_REMOVE_FORMAT,
			  "E_CONTENT_EDITOR_COMMAND_REMOVE_FORMAT",
			  "remove-format" },
			{ E_CONTENT_EDITOR_COMMAND_SELECT_ALL,
			  "E_CONTENT_EDITOR_COMMAND_SELECT_ALL",
			  "select-all" },
			{ E_CONTENT_EDITOR_COMMAND_STRIKETHROUGH,
			  "E_CONTENT_EDITOR_COMMAND_STRIKETHROUGH",
			  "strikethrough" },
			{ E_CONTENT_EDITOR_COMMAND_STYLE_WITH_CSS,
			  "E_CONTENT_EDITOR_COMMAND_STYLE_WITH_CSS",
			  "style-with-css" },
			{ E_CONTENT_EDITOR_COMMAND_SUBSCRIPT,
			  "E_CONTENT_EDITOR_COMMAND_SUBSCRIPT",
			  "subscript" },
			{ E_CONTENT_EDITOR_COMMAND_SUPERSCRIPT,
			  "E_CONTENT_EDITOR_COMMAND_SUPERSCRIPT",
			  "superscript" },
			{ E_CONTENT_EDITOR_COMMAND_TRANSPOSE,
			  "E_CONTENT_EDITOR_COMMAND_TRANSPOSE",
			  "transpose" },
			{ E_CONTENT_EDITOR_COMMAND_UNDERLINE,
			  "E_CONTENT_EDITOR_COMMAND_UNDERLINE",
			  "underline" },
			{ E_CONTENT_EDITOR_COMMAND_UNDO,
			  "E_CONTENT_EDITOR_COMMAND_UNDO",
			  "undo" },
			{ E_CONTENT_EDITOR_COMMAND_UNLINK,
			  "E_CONTENT_EDITOR_COMMAND_UNLINK",
			  "unlink" },
			{ E_CONTENT_EDITOR_COMMAND_UNSELECT,
			  "E_CONTENT_EDITOR_COMMAND_UNSELECT",
			  "unselect" },
			{ E_CONTENT_EDITOR_COMMAND_USE_CSS,
			  "E_CONTENT_EDITOR_COMMAND_USE_CSS",
			  "use-css" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EContentEditorCommand"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_scope_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_CONTENT_EDITOR_SCOPE_CELL,
			  "E_CONTENT_EDITOR_SCOPE_CELL",
			  "cell" },
			{ E_CONTENT_EDITOR_SCOPE_ROW,
			  "E_CONTENT_EDITOR_SCOPE_ROW",
			  "row" },
			{ E_CONTENT_EDITOR_SCOPE_COLUMN,
			  "E_CONTENT_EDITOR_SCOPE_COLUMN",
			  "column" },
			{ E_CONTENT_EDITOR_SCOPE_TABLE,
			  "E_CONTENT_EDITOR_SCOPE_TABLE",
			  "table" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EContentEditorScope"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_unit_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_CONTENT_EDITOR_UNIT_AUTO,
			  "E_CONTENT_EDITOR_UNIT_AUTO",
			  "auto" },
			{ E_CONTENT_EDITOR_UNIT_PIXEL,
			  "E_CONTENT_EDITOR_UNIT_PIXEL",
			  "pixel" },
			{ E_CONTENT_EDITOR_UNIT_PERCENTAGE,
			  "E_CONTENT_EDITOR_UNIT_PERCENTAGE",
			  "percentage" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EContentEditorUnit"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_find_flags_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GFlagsValue values[] = {
			{ E_CONTENT_EDITOR_FIND_NEXT,
			  "E_CONTENT_EDITOR_FIND_NEXT",
			  "next" },
			{ E_CONTENT_EDITOR_FIND_PREVIOUS,
			  "E_CONTENT_EDITOR_FIND_PREVIOUS",
			  "previous" },
			{ E_CONTENT_EDITOR_FIND_MODE_BACKWARDS,
			  "E_CONTENT_EDITOR_FIND_MODE_BACKWARDS",
			  "mode-backwards" },
			{ E_CONTENT_EDITOR_FIND_CASE_INSENSITIVE,
			  "E_CONTENT_EDITOR_FIND_CASE_INSENSITIVE",
			  "case-insensitive" },
			{ E_CONTENT_EDITOR_FIND_WRAP_AROUND,
			  "E_CONTENT_EDITOR_FIND_WRAP_AROUND",
			  "wrap-around" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_flags_register_static (
			g_intern_static_string ("EContentEditorFindFlags"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_content_editor_mode_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_CONTENT_EDITOR_MODE_UNKNOWN,
			  "E_CONTENT_EDITOR_MODE_UNKNOWN",
			  "unknown" },
			{ E_CONTENT_EDITOR_MODE_PLAIN_TEXT,
			  "E_CONTENT_EDITOR_MODE_PLAIN_TEXT",
			  "plain-text" },
			{ E_CONTENT_EDITOR_MODE_HTML,
			  "E_CONTENT_EDITOR_MODE_HTML",
			  "html" },
			{ E_CONTENT_EDITOR_MODE_MARKDOWN,
			  "E_CONTENT_EDITOR_MODE_MARKDOWN",
			  "markdown" },
			{ E_CONTENT_EDITOR_MODE_MARKDOWN_PLAIN_TEXT,
			  "E_CONTENT_EDITOR_MODE_MARKDOWN_PLAIN_TEXT",
			  "markdown-plain-text" },
			{ E_CONTENT_EDITOR_MODE_MARKDOWN_HTML,
			  "E_CONTENT_EDITOR_MODE_MARKDOWN_HTML",
			  "markdown-html" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EContentEditorMode"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_undo_redo_state_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GFlagsValue values[] = {
			{ E_UNDO_REDO_STATE_NONE,
			  "E_UNDO_REDO_STATE_NONE",
			  "none" },
			{ E_UNDO_REDO_STATE_CAN_UNDO,
			  "E_UNDO_REDO_STATE_CAN_UNDO",
			  "can-undo" },
			{ E_UNDO_REDO_STATE_CAN_REDO,
			  "E_UNDO_REDO_STATE_CAN_REDO",
			  "can-redo" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_flags_register_static (
			g_intern_static_string ("EUndoRedoState"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_dn_dtarget_type_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_DND_TARGET_TYPE_TEXT_URI_LIST,
			  "E_DND_TARGET_TYPE_TEXT_URI_LIST",
			  "text-uri-list" },
			{ E_DND_TARGET_TYPE_MOZILLA_URL,
			  "E_DND_TARGET_TYPE_MOZILLA_URL",
			  "mozilla-url" },
			{ E_DND_TARGET_TYPE_TEXT_HTML,
			  "E_DND_TARGET_TYPE_TEXT_HTML",
			  "text-html" },
			{ E_DND_TARGET_TYPE_UTF8_STRING,
			  "E_DND_TARGET_TYPE_UTF8_STRING",
			  "utf8-string" },
			{ E_DND_TARGET_TYPE_TEXT_PLAIN,
			  "E_DND_TARGET_TYPE_TEXT_PLAIN",
			  "text-plain" },
			{ E_DND_TARGET_TYPE_STRING,
			  "E_DND_TARGET_TYPE_STRING",
			  "string" },
			{ E_DND_TARGET_TYPE_TEXT_PLAIN_UTF8,
			  "E_DND_TARGET_TYPE_TEXT_PLAIN_UTF8",
			  "text-plain-utf8" },
			{ E_DND_TARGET_TYPE_TEXT_X_MOZ_URL,
			  "E_DND_TARGET_TYPE_TEXT_X_MOZ_URL",
			  "text-x-moz-url" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EDnDTargetType"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_config_lookup_source_kind_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_CONFIG_LOOKUP_SOURCE_UNKNOWN,
			  "E_CONFIG_LOOKUP_SOURCE_UNKNOWN",
			  "unknown" },
			{ E_CONFIG_LOOKUP_SOURCE_COLLECTION,
			  "E_CONFIG_LOOKUP_SOURCE_COLLECTION",
			  "collection" },
			{ E_CONFIG_LOOKUP_SOURCE_MAIL_ACCOUNT,
			  "E_CONFIG_LOOKUP_SOURCE_MAIL_ACCOUNT",
			  "mail-account" },
			{ E_CONFIG_LOOKUP_SOURCE_MAIL_IDENTITY,
			  "E_CONFIG_LOOKUP_SOURCE_MAIL_IDENTITY",
			  "mail-identity" },
			{ E_CONFIG_LOOKUP_SOURCE_MAIL_TRANSPORT,
			  "E_CONFIG_LOOKUP_SOURCE_MAIL_TRANSPORT",
			  "mail-transport" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EConfigLookupSourceKind"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_config_lookup_result_kind_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_CONFIG_LOOKUP_RESULT_UNKNOWN,
			  "E_CONFIG_LOOKUP_RESULT_UNKNOWN",
			  "unknown" },
			{ E_CONFIG_LOOKUP_RESULT_COLLECTION,
			  "E_CONFIG_LOOKUP_RESULT_COLLECTION",
			  "collection" },
			{ E_CONFIG_LOOKUP_RESULT_MAIL_RECEIVE,
			  "E_CONFIG_LOOKUP_RESULT_MAIL_RECEIVE",
			  "mail-receive" },
			{ E_CONFIG_LOOKUP_RESULT_MAIL_SEND,
			  "E_CONFIG_LOOKUP_RESULT_MAIL_SEND",
			  "mail-send" },
			{ E_CONFIG_LOOKUP_RESULT_ADDRESS_BOOK,
			  "E_CONFIG_LOOKUP_RESULT_ADDRESS_BOOK",
			  "address-book" },
			{ E_CONFIG_LOOKUP_RESULT_CALENDAR,
			  "E_CONFIG_LOOKUP_RESULT_CALENDAR",
			  "calendar" },
			{ E_CONFIG_LOOKUP_RESULT_MEMO_LIST,
			  "E_CONFIG_LOOKUP_RESULT_MEMO_LIST",
			  "memo-list" },
			{ E_CONFIG_LOOKUP_RESULT_TASK_LIST,
			  "E_CONFIG_LOOKUP_RESULT_TASK_LIST",
			  "task-list" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EConfigLookupResultKind"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_markdown_html_to_text_flags_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GFlagsValue values[] = {
			{ E_MARKDOWN_HTML_TO_TEXT_FLAG_NONE,
			  "E_MARKDOWN_HTML_TO_TEXT_FLAG_NONE",
			  "none" },
			{ E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT,
			  "E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT",
			  "plain-text" },
			{ E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS,
			  "E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS",
			  "composer-quirks" },
			{ E_MARKDOWN_HTML_TO_TEXT_FLAG_SIGNIFICANT_NL,
			  "E_MARKDOWN_HTML_TO_TEXT_FLAG_SIGNIFICANT_NL",
			  "significant-nl" },
			{ E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_INLINE,
			  "E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_INLINE",
			  "link-inline" },
			{ E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_REFERENCE,
			  "E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_REFERENCE",
			  "link-reference" },
			{ E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_REFERENCE_WITHOUT_LABEL,
			  "E_MARKDOWN_HTML_TO_TEXT_FLAG_LINK_REFERENCE_WITHOUT_LABEL",
			  "link-reference-without-label" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_flags_register_static (
			g_intern_static_string ("EMarkdownHTMLToTextFlags"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_markdown_text_to_html_flags_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GFlagsValue values[] = {
			{ E_MARKDOWN_TEXT_TO_HTML_FLAG_NONE,
			  "E_MARKDOWN_TEXT_TO_HTML_FLAG_NONE",
			  "none" },
			{ E_MARKDOWN_TEXT_TO_HTML_FLAG_INCLUDE_SOURCEPOS,
			  "E_MARKDOWN_TEXT_TO_HTML_FLAG_INCLUDE_SOURCEPOS",
			  "include-sourcepos" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_flags_register_static (
			g_intern_static_string ("EMarkdownTextToHTMLFlags"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_toolbar_icon_size_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_TOOLBAR_ICON_SIZE_DEFAULT,
			  "E_TOOLBAR_ICON_SIZE_DEFAULT",
			  "default" },
			{ E_TOOLBAR_ICON_SIZE_SMALL,
			  "E_TOOLBAR_ICON_SIZE_SMALL",
			  "small" },
			{ E_TOOLBAR_ICON_SIZE_LARGE,
			  "E_TOOLBAR_ICON_SIZE_LARGE",
			  "large" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EToolbarIconSize"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_prefer_symbolic_icons_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_PREFER_SYMBOLIC_ICONS_NO,
			  "E_PREFER_SYMBOLIC_ICONS_NO",
			  "no" },
			{ E_PREFER_SYMBOLIC_ICONS_YES,
			  "E_PREFER_SYMBOLIC_ICONS_YES",
			  "yes" },
			{ E_PREFER_SYMBOLIC_ICONS_AUTO,
			  "E_PREFER_SYMBOLIC_ICONS_AUTO",
			  "auto" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EPreferSymbolicIcons"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_html_link_to_text_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_HTML_LINK_TO_TEXT_NONE,
			  "E_HTML_LINK_TO_TEXT_NONE",
			  "none" },
			{ E_HTML_LINK_TO_TEXT_INLINE,
			  "E_HTML_LINK_TO_TEXT_INLINE",
			  "inline" },
			{ E_HTML_LINK_TO_TEXT_REFERENCE,
			  "E_HTML_LINK_TO_TEXT_REFERENCE",
			  "reference" },
			{ E_HTML_LINK_TO_TEXT_REFERENCE_WITHOUT_LABEL,
			  "E_HTML_LINK_TO_TEXT_REFERENCE_WITHOUT_LABEL",
			  "reference-without-label" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EHTMLLinkToText"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_ui_element_kind_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GFlagsValue values[] = {
			{ E_UI_ELEMENT_KIND_UNKNOWN,
			  "E_UI_ELEMENT_KIND_UNKNOWN",
			  "unknown" },
			{ E_UI_ELEMENT_KIND_ROOT,
			  "E_UI_ELEMENT_KIND_ROOT",
			  "root" },
			{ E_UI_ELEMENT_KIND_HEADERBAR,
			  "E_UI_ELEMENT_KIND_HEADERBAR",
			  "headerbar" },
			{ E_UI_ELEMENT_KIND_TOOLBAR,
			  "E_UI_ELEMENT_KIND_TOOLBAR",
			  "toolbar" },
			{ E_UI_ELEMENT_KIND_MENU,
			  "E_UI_ELEMENT_KIND_MENU",
			  "menu" },
			{ E_UI_ELEMENT_KIND_SUBMENU,
			  "E_UI_ELEMENT_KIND_SUBMENU",
			  "submenu" },
			{ E_UI_ELEMENT_KIND_PLACEHOLDER,
			  "E_UI_ELEMENT_KIND_PLACEHOLDER",
			  "placeholder" },
			{ E_UI_ELEMENT_KIND_SEPARATOR,
			  "E_UI_ELEMENT_KIND_SEPARATOR",
			  "separator" },
			{ E_UI_ELEMENT_KIND_START,
			  "E_UI_ELEMENT_KIND_START",
			  "start" },
			{ E_UI_ELEMENT_KIND_END,
			  "E_UI_ELEMENT_KIND_END",
			  "end" },
			{ E_UI_ELEMENT_KIND_ITEM,
			  "E_UI_ELEMENT_KIND_ITEM",
			  "item" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_flags_register_static (
			g_intern_static_string ("EUIElementKind"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_ui_parser_export_flags_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GFlagsValue values[] = {
			{ E_UI_PARSER_EXPORT_FLAG_NONE,
			  "E_UI_PARSER_EXPORT_FLAG_NONE",
			  "none" },
			{ E_UI_PARSER_EXPORT_FLAG_INDENT,
			  "E_UI_PARSER_EXPORT_FLAG_INDENT",
			  "indent" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_flags_register_static (
			g_intern_static_string ("EUIParserExportFlags"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}
GType
e_message_popover_flags_get_type (void)
{
	static gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GFlagsValue values[] = {
			{ E_MESSAGE_POPOVER_FLAG_NONE,
			  "E_MESSAGE_POPOVER_FLAG_NONE",
			  "none" },
			{ E_MESSAGE_POPOVER_FLAG_INFO,
			  "E_MESSAGE_POPOVER_FLAG_INFO",
			  "info" },
			{ E_MESSAGE_POPOVER_FLAG_WARNING,
			  "E_MESSAGE_POPOVER_FLAG_WARNING",
			  "warning" },
			{ E_MESSAGE_POPOVER_FLAG_ERROR,
			  "E_MESSAGE_POPOVER_FLAG_ERROR",
			  "error" },
			{ E_MESSAGE_POPOVER_FLAG_HIGHLIGHT_POPOVER,
			  "E_MESSAGE_POPOVER_FLAG_HIGHLIGHT_POPOVER",
			  "highlight-popover" },
			{ E_MESSAGE_POPOVER_FLAG_HIGHLIGHT_WIDGET,
			  "E_MESSAGE_POPOVER_FLAG_HIGHLIGHT_WIDGET",
			  "highlight-widget" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_flags_register_static (
			g_intern_static_string ("EMessagePopoverFlags"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

/* Generated data ends here */

